**********************
*PLEASE CITE PAPER AS:
*Zarach, Z. H., Parteka, A. (2023). Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization. The World Economy

***********************************************
*IF YOU USE REPLICATION PACKAGE PLEASE CITE AS:
*Zarach, Z. H., & Parteka, A. (2023). Data accompanying the paper: "Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization" (Zarach and Parteka, The World Economy, 2023) [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/2cf4-9e23

***************************************
*THIS DO.FILE CREATES BASELINE DATABASE
***************************************

****************
*IMPORTANT NOTE!
****************
*Since source data used in this do.file may have been updated between today and the time when it was downloaded by authors, this baseline database might marginally vary from the one originally used by the authors, as far as data is concerned.
*Therefore, some differences in estimations results and summary statistics may occur, compared to results reported in abovementioned paper. 
*Versions of databases used by the authors (as well as the date of downloading them) are given below, next to every information regarding respective source data. 

/*_____________________________________________________________________________*/
/*First you have to create a following folder structure:

NR_PRODUCTIVITY
	|_ DATA
		|_ SOURCE_DATA
	
All source files are to be stored in SOURCE_DATA catalogue*/


//Setting a directory//
clear all
set more off
cd  "D:\NR_PRODUCTIVITY\DATA"

*______________________________________________________________________________*
//PART 1: DATA ON COUNTRY SPECIFIC INDICATORS AND CLASSIFICATIONS//
********************************************************************************
//Step 1: preparation of country-level data on productivity per employee from Penn World Table//
**Please download PWT database in Stata version from https://www.rug.nl/ggdc/productivity/pwt/?lang=en**
**To match all codes in do.files, please name your downloaded file as: pwt.dta and set it in SOURCE DATA catalogue**
**Version downloaded by authors: PWT 10.0 (date: 01.2022)**
use "SOURCE_DATA\pwt.dta", clear
keep countrycode year rgdpna emp ctfp
keep if year>=1996 & year<=2018

*Replacing separate data for BEL and LUX with joint data for BELX (to match with country codes in our trade database)
replace countrycode="BELX" if countrycode=="BEL"
replace countrycode="BELX" if countrycode=="LUX"
collapse (sum) rgdpna emp (mean) ctfp, by (countrycode year)

*Labelling variables
la var rgdpna "Real GDP at constant 2017 national prices (in mil. 2017US$)"
la var emp "Number of persons engaged (in millions)"
la var countrycode "3-letter country name abbreviation"
la var ctfp "TFP level at current PPPs (USA=1)"
la var year "1996-2018"

*Saving the database
save pwt_19962018.dta, replace  

********************************************************************************
//Step 2: including income classification based on historical records from World Bank (1996-2018)//
**Please download historical classification by income from https://datahelpdesk.worldbank.org/knowledgebase/articles/906519-world-bank-country-and-lending-groups**
**To match all codes in do.files, please name your downloaded file as: World Bank -  historical classification by income.xlsx and set it in SOURCE DATA catalogue**
**Version downloaded by authors: 12.2021**
**H, M, LM, UM - high, middle, low-middle, upper-middle income**
**This classification is country and time(year) specific**

clear all
import excel "SOURCE_DATA\World Bank -  historical classification by income.xlsx", sheet("Country Analytical History") clear

*Removing unnecessary lines and variables
drop in 1/11
drop in 219/229

drop B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE AF AG AI AJ AK AL AM AN AO AP AQ AR AS AT AU AV AW AX AY AZ BA BB BC BD BE BF BG BH BI BJ BK BL BM BN BO BP BQ
drop BR BS BT BU BV BW BX BY BZ CA CB CC CD CE CF CG CH CI CJ CK CL CM CN CO CP CQ CR CS CT CU CV CW CX CY CZ DA DB DC DD DE DF DG DH DI DJ DK DL DM DN DO DP DQ DR DS DT DU DV DW DX
drop DY DZ EA EB EC ED EE EF EG EH EI EJ EK EL EM EN EO EP EQ ER ES ET EU EV EW EX EY EZ FA FB FC FD FE FF FG FH FI FJ FK FL FM FN FO FP FQ FR FS FT FU FV FW FX FY FZ GA GB GC GD GE
drop GF GG GH GI GJ GK GL GM GN GO GP GQ GR GS GT GU GV GW GX GY GZ HA HB HC HD HE HF HG HH HI HJ HK HL HM HN HO HP HQ HR HS HT HU HV HW HX HY HZ IA IB IC ID IE IF IG IH II IJ IK IL IM IN IO IP IQ IR IS IT IU 

*Renaming remaining variables to match other source databases
rename A countrycode
rename AH CLS2018
la var countrycode "3-letter country name abbreviation"
la var CLS2018 "Income classification, year 2018"

*Unifying classification for BEL and LUX 
drop if countrycode=="LUX"
replace countrycode="BELX" if countrycode=="BEL"

*Creating dummy variable acknowledging developed (high-income) countries (as of 2018 - World Bank income classification)
gen developed=.
replace developed=1 if CLS2018 == "H"
replace developed=0 if CLS2018 != "H"
la var developed "Income classification; developed countries=1"

*Saving the database
save income_classification.dta, replace

********************************************************************************
//Step 3: including data on natural resource rents (alternative measure of natural resource endowment)//
**Please download data on coal, forest, mineral, gas, oil and total resource rents from World Development Indicators (for all available countries and timespan of 1996-2018): https://databank.worldbank.org/source/world-development-indicators**
**To match all codes in do.files, please name your downloaded file as: Data_Extract_From_World_Development_Indicators.xlsx and set it in SOURCE DATA catalogue**
**Version downloaded by authors: 01.2022**

clear all
import excel "SOURCE_DATA\Data_Extract_From_World_Development_Indicators.xlsx", sheet("Data") firstrow clear

*Removing unnecessary lines and variables; renaming variables to match other source databases
drop in 1303/1307
drop SeriesCode CountryName
rename CountryCode countrycode
rename SeriesName index

*Replacing missing data and destringing variables
forvalues i = 1996/2018 {
foreach var in YR`i' {
replace `var'="." if `var'==".."
}
foreach var in YR`i' {
destring `var', replace
}
}

*Reshaping the database from wide to long format
reshape long YR, j(year) i(index countrycode) s
destring year, replace

*Destringing variables into float format 
encode index, generate(ind_des)
rename YR value
drop index

*Reshaping the database from long to wide format
reshape wide value, j(ind_des ) i(countrycode year) 

*Renaming variables
rename value1 coal
rename value2 forest
rename value3 mineral
rename value4 gas
rename value5 oil 
rename value6 total

*Replacing separate data for BEL and LUX with joint data for BELX (to match with country codes in our trade database)
replace countrycode="BELX" if countrycode=="BEL"
replace countrycode="BELX" if countrycode=="LUX"
collapse (sum) coal forest mineral gas oil total, by (countrycode year)

*Labelling variables
la var coal "Coal rents (% of GDP)"
la var forest "Forest rents (% of GDP)"
la var mineral "Mineral rents (% of GDP)"
la var gas "Natural gas rents (% of GDP)"
la var oil "Oil rents (% of GDP)"
la var total "Total natural resources rents (% of GDP)"
la var countrycode "3-letter country name abbreviation"
la var year "1996-2018"

*Saving the database
save resource_rents.dta, replace

********************************************************************************
//Step 4: including data on future control variables (R&D expenditures, Human Capital Index, level of investment)//
**Please download data on R&D expenditure (% of GDP), Human capital index (scale 0-1) and Gross fixed capital formation (% of GDP) from World Development Indicators (for all available countries and timespan of 1996-2018): https://databank.worldbank.org/source/world-development-indicators**
**To match all codes in do.files, please name your downloaded file as: Data_Extract_From_World_Development_Indicators(1).xlsx and set it in SOURCE DATA catalogue**
**Version downloaded by authors: 01.2022**

clear all
import excel "SOURCE_DATA\Data_Extract_From_World_Development_Indicators(1).xlsx", sheet("Data") firstrow clear

*Removing unnecessary lines and variables; renaming variables to match other source databases
drop in 652/656
drop SeriesCode CountryName
rename CountryCode countrycode
rename SeriesName index

*Replacing missing data and destringing variables
forvalues i = 1996/2018 {
foreach var in YR`i' {
replace `var'="." if `var'==".."
}
foreach var in YR`i' {
destring `var', replace
}
}

*Reshaping the database from wide to long format
reshape long YR, j(year) i(index countrycode) s
destring year, replace

*Destringing variables into float format 
encode index, generate(ind_des)
rename YR value
drop index

*Reshaping the database from long to wide format
reshape wide value, j(ind_des ) i(countrycode year) 

*Renaming variables
rename value1 INV
rename value2 HC
rename value3 RDexpend

*Replacing separate data for BEL and LUX with joint data for BELX (to match with country codes in our trade database)
replace countrycode="BELX" if countrycode=="BEL"
replace countrycode="BELX" if countrycode=="LUX"
collapse (sum) INV HC RDexpend, by (countrycode year)

*Labelling variables
la var INV "Gross fixed capital formation (% of GDP)"
la var HC "Human capital index (HCI) (scale 0-1)"
la var RDexpend "Research and development expenditure (% of GDP)"
la var countrycode "3-letter country name abbreviation"
la var year "1996-2018"

*Saving the database
save control_variables.dta, replace

*______________________________________________________________________________*
//PART 2: TRADE DATA AND TRADE PRODUCTS' CLASSIFICATIONS//
********************************************************************************
//Step 1: Country codes//
**This file associates the ISO 3-digit numeric codes used in BACI databases with country full names and 3-letter country name abbreviation used in other source databases**
**This file accompanies core BACI trade data files**
**File country_codes_V202102_v1.csv included in the replication package; please set it in your SOURCE DATA catalogue**

clear all
import delimited "SOURCE_DATA\country_codes_V202102_v1.csv", clear

*Removing unnecessary variables
drop iso_2digit_alpha country_name_full

*Renaming variables to match other source databases
rename country_name_abbreviation countryname
rename iso_3digit_alpha countrycode
rename country_code Exporter

*Ordering and renaming variables
gen Importer = Exporter
order countrycode countryname Exporter Importer

la var countrycode "3-letter country name abbreviation"
la var countryname "Countries' full names"

*Saving the database
save country_codes.dta, replace

********************************************************************************
//Step 2: Trade products' classifications//
**Product-level (HS 6 digit) taxonomies: for natural resources and technologically advanced products**
**More information regarding used classifications to be found in file taxonomies_v1.xlsx included as a supplementary file to the paper (also available in replication package)**
**File classifications_v1.xlsx included in the replication package; please set it in your SOURCE DATA catalogue**

clear all
******************
*NATURAL RESOURCES
******************
import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("TOTAL NR") firstrow clear
la var TOTAL_NR "=1 if products belong to all 4 resource groups: metal, fuel, mineral, forest"
save TOTAL_NR.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("FORESTRY") firstrow clear
la var FORESTRY "=1 if products belong to FORESTRY group"
save FORESTRY.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("FUEL") firstrow clear
la var FUEL "=1 if products belong to FUEL group"
save FUEL.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("METAL") firstrow clear
la var METAL "=1 if products belong to METAL group"
save METAL.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("MINERAL") firstrow clear
la var MINERAL "=1 if products belong to MINERAL group"
save MINERAL.dta, replace

**********************************
*TECHNOLOGICALLY ADVANCED PRODUCTS
**********************************
import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("4IR") firstrow clear
la var FOUR_IR "=1 if products belong to 4IR group"
save FOUR_IR.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("ICT") firstrow clear
la var ICT "=1 if products belong to ICT group"
save ICT.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("TECH") firstrow clear
la var TECH "=1 if products belong to TECH group"
save TECH.dta, replace

**************
*PRODUCT CODES
**************
**This file associates the HS 6-digit product codes to product names and accompanies core BACI trade data files**
**File product_codes_HS96_V202102_v1.csv included in the replication package; please set it in your SOURCE DATA catalogue**

clear all
import delimited "SOURCE_DATA\product_codes_HS96_V202102_v1.csv", varnames(1) clear

*Cleaning data and prepering for the merge
drop if code=="9999AA"
destring code, generate (ProductCode)
drop code
rename description ProductDescription
order ProductCode ProductDescription

*Labelling variables
la var ProductCode "6-digit product codes in compliance with HS96 nomenclature"
la var ProductDescription "Product names in compliance with HS96 nomenclature"

*Merging all classification files
foreach k in TOTAL_NR FORESTRY FUEL METAL MINERAL FOUR_IR ICT TECH{
merge m:m ProductCode using "`k'.dta", force
replace `k'=0 if `k'==.
drop if _merge==2
drop _merge
erase `k'.dta
}

*Saving the database
save product_codes.dta, replace

********************************************************************************
//Step 3: Product-level bilateral trade flows//
**Please download an archival version of BACI CEPII HS96 database (i.e. 202102 version) from http://www.cepii.fr/CEPII/en/bdd_modele/bdd_modele_item.asp?id=37 (to be found in tab ARCHIVES)**
**Please create a separate folder within SOURCE DATA catalogue and name it BACI_HS96_V202102; then put all source trade data files downloaded from CEPII's BACI repository in this folder**
**BACI CEPII provides yearly product-level data on bilateral trade flows; only the strictly positive trade flows are recorded; trade flows below 1000 USD value do not appear; BACI databases are free from UN Special Codes**

/*letters used as variable names stand for:
t -> Year during which the recorded trade flows took place
i -> Exporter (ISO 3-digit country code)
j -> Importer (ISO 3-digit country code)
v -> Value of the trade flow (in thousands current USD)
k -> Product category (HS 6-digit code)
q -> Quantity (in metric tons)
*/

clear all
set more off
forvalues i = 1996/2018 {
import delimited "SOURCE_DATA\BACI_HS96_V202102\BACI_HS96_Y`i'_V202102.csv", clear
save "SOURCE_DATA\BACI_HS96_V202102\BACI_HS96_Y`i'_V202102.dta", replace
}
**********************
*Initial data cleaning
********************** 
forvalues i = 1996/2018 {
use "SOURCE_DATA\BACI_HS96_V202102\BACI_HS96_Y`i'_V202102.dta", clear

*Dropping Custom Unions, Trade Unions and countries which don't exist in 1996-2018 timespan: 230"Former Ethiopia" 278"NRD" 280"RFN" 490"Other Asia, not elsewhere specified" 697"Europe EFTA, not elsewhere specified" 711"Southern African Customs Union" 810"Former USSR Soviet Union" 849"US Miscellaneous Pacific Islands"
foreach n in 230 278 280 490 697 711 810 849{
drop if i == `n'
drop if j == `n'
}

*Deleting unnecessary variables and renaming remaining ones 
drop q
rename i Exporter
rename j Importer
rename v Value
rename k ProductCode
rename t year

*Changing country numbers for 3-letter country codes; both for Exporter and Importer
foreach k in Exporter Importer{
merge m:m `k' using "country_codes.dta", force
drop if _merge==2
drop _merge 
drop `k' 
rename countrycode `k'
}

*Labeling variables
la var Importer "Importer (3-letter country code)"
la var Exporter "Exporter (3-letter country code)"
la var Value "Value of the trade flow (in thousands current USD)"
la var ProductCode "Product category (HS 6-digit code)"
la var year "1996-2018"

**********************
*Further data cleaning
**********************
*Deleting UN Special Codes (other than 9999AA, which is not included in BACI databases)
foreach k in 151930 271011 271012 271013 271014 271015 271016 271019 271021 271022 271025 271026 271027 271029 271091 271093 271094 271095 271096 271099 380999 5127 5131{
drop if ProductCode ==	`k'
}
*Deleting product codes which vanish throughout the 1996-2018 timespan (i.e. product codes no longer used in HS96 nomenclature in further years or not changed into new product code with conversion tables; step taken to obtain a balanced dataset)
foreach k in 10120 20820 50300 71110 81220 110312 110314 110411 110421 120792 120919 120926 121110 121230 130110 130214 140210 140310 140390 150510 151540 151560 200120 230670 230810 250621 251621 252700 253040 262050 270760 280522 281123 281620{
drop if ProductCode == `k'
}
foreach k in 282733 282734 282736 282738 283020 283030 283323 283422 283523 283670 283800 284110 284140 290316 290343 290344 290515 290614 290714 290730 290820 290942 291213 291230 291523 291534 291535 291635 291731 291817 292112 292222 293010 293221 293610 293729 293921 293970 310270 310320 310410 320630 320643 330121 330122 330126 370251 370291{
drop if ProductCode == `k'
}
foreach k in 370292 381720 392041 410122 410129 410140 410310 410410 410421 410511 410512 410611 410612 410721 420610 430120 430140 430150 430170 430212 430213 441111 441191 441222 460110 480521 480522 480523 480710 481012 481410 482351 482359 500310 520853 521012 521022 521042 521052 521121{
drop if ProductCode == `k'
}
foreach k in 521122 530410 530490 530511 530519 530521 530529 530591 530830 540320 551322 551342 551413 551432 551592 560730 570251 570252 580124 580134 590491 600241 610110 610321 610411 610421 611410 620321 630641 640191 640330 650692 660310 681210 681220 681230 681240 701091 701093 701094 722520 722693{
drop if ProductCode == `k'
}
foreach k in 722694 722910 730220 731413 740120 740323 740722 741420 741531 741600 780300 780500 800600 810192 811230 811240 841822 842850 843062 844210 844220 844841 845691 846110 846911 846912 846930 847040 850890 852431 854050 854072 854214 854219 854311 860620 880110 901041 903130 910112 910620 910891 911210 920410 920920 930521 961330 710820 711890 999999{
drop if ProductCode == `k'
}
foreach k in 701200 842520 852010 911420 441139{
drop if ProductCode == `k'
}
***********************************************************************************************************************************************************************************
*Following two steps taken in order to maintain the same set of countries ("WORLD") for which trade and output per worker (GDP/emp) data is available throughout the whole timespan
***********************************************************************************************************************************************************************************
*Deleting countries with incomplete data (countries not providing data for every year throughout 1996-2018 and countries which gained independence during 1996-2018 timespan e.g. Serbia (SRB))
foreach country in "ASM" "BWA" "GUM" "LSO" "MYT" "NAM" "PSE" "SMR" "SWZ" "ZAF" "CUW" "BES" "SXM" "ANT" "SSD" "BLM" "SCG" "MNE" "SRB"{
drop if Exporter == "`country'"
drop if Importer == "`country'"
}
*Deleting countries with population<100k and countries for which there is no GDP and employment data in PWT10.0
foreach country in "ABW" "AFG" "AIA" "AND" "ATF" "ATG" "BMU" "CCK" "COK" "CUB" "CXR" "CYM" "DMA" "FLK" "FSM" "GIB" "GRL" "IOT" "KIR" "KNA" "LBY" "MHL" "MNP" "MSR" "NCL" "NFK" "NIU" "NRU" "PCN" "PLW" "PNG" "PRK" "PYF" "SHN" "SLB" "SOM" "SPM" "SYC" "TCA" "TKL" "TLS" "TON" "TUV" "VGB" "VUT" "WLF" "WSM"{
drop if Exporter == "`country'"
drop if Importer == "`country'"
}

*Preparing joint data for Belgium (BEL) and Luxemburg (LUX) (under the abbreviation BELX) to match the trend from year 1996, 1997 and 1998 where data for BEL and LUX appear as a sum under the abbreviation BEL
replace Exporter="BELX" if Exporter=="BEL" | Exporter=="LUX"
replace Importer="BELX" if Importer=="BEL" | Importer=="LUX"
replace countryname="Belgium and Luxembourg" if Exporter=="BELX"
collapse (sum) Value , by (Exporter ProductCode Importer countryname year)
la var Value "Export value (in thousands current USD)"


************************************************
*Change from bilateral into unilateral dimension 
************************************************
*Deleting Importer variable
collapse (sum) Value, by (Exporter ProductCode countryname year)
la var Value "Export value (in thousands current USD)"
rename Exporter countrycode

*Adding product classifications
merge m:m ProductCode using "product_codes.dta"
drop if _merge==2
drop _merge


save trade-data-`i'.dta, replace
}
********************************************************************************
//Step 4: Country-level indicators based on trade data//
**Calculating export shares for natural resources and technological products**
clear all
set more off
forvalues i = 1996/2018 {

use trade-data-`i'.dta, clear

/*Before following calculations, xfill command needs to be downloaded and installed. To obtain xfill please type the following into Stata:
net from https://www.sealedenvelope.com/
and follow the instructions on screen*/

*Rectangulizing the dataset (in order to obtain a full matrix of products for all countries (even if actual export value is missing))
fillin ProductCode countrycode
drop _fillin
egen CountryNumber=group(countrycode)
order CountryNumber, before(ProductCode)
replace year=`i' if year==.

foreach z in countryname countrycode{
xfill `z', i(CountryNumber)
}
************************************************************
*Calculating total exports and export shares -> all products
************************************************************
*Countries' total exports
egen Ec = total(Value), by (countrycode)
la var Ec "Country total exports"
*Worlds' total exports
egen Ew = total(Value)
la var Ew "World's total exports"
*Share of countries' export in world's exports
gen Scw = Ec/Ew
la var Scw "Share of countries' total exports in world's total exports"

**************************************************************
*Calculating total exports and export shares -> product groups
**************************************************************
foreach k in TOTAL_NR FORESTRY FUEL METAL MINERAL FOUR_IR ICT TECH{
*Countries' total exports (by product groups)
egen Ec`k' = total(Value) if `k'==1,   by (countrycode)
xfill Ec`k', i(CountryNumber)
la var Ec`k' "Country total exports (`k' group)"

*Worlds' total exports (by product groups)
egen Ew`k' = total(Value) if `k'==1
xfill Ew`k', i(CountryNumber)
la var Ew`k' "World's total exports (`k' group)"

*Share of group's exports in countries'(world's) total exports 
gen Sc`k' = Ec`k'/Ec
la var Sc`k' "Share of group `k' in country total exports"
gen Sw`k' = Ew`k'/Ew
la var Sw`k' "Share of group `k' in world's total exports"

*Share of countries' export in world's exports (by product groups)
gen Scw`k' = Ec`k'/Ew`k'
xfill Scw`k', i(CountryNumber)
la var Scw`k' "Share of countries' exports in world's exports (group `k')"

*************************************
*Revealed Comparative Advantage (RCA)
*************************************
gen RCA`k' = Sc`k'/Sw`k'
la var RCA`k' "Revealed Comparative Advantage (group `k' products)"
}
save country-level-indicators-`i'.dta, replace 
}
*______________________________________________________________________________*
//PART 3: MERGING ALL SOURCE DATABASES//
********************************************************************************
**Creating final database entitled TheWorldEconomy_ZarachParteka_BaselineData.dta**
clear all
set more off
*Collapsing country- and year-specific trade databases into one database
forvalues i = 1996/2018 {
foreach k in TOTAL_NR FORESTRY FUEL METAL MINERAL FOUR_IR ICT TECH{
use country-level-indicators-`i'.dta
collapse RCA`k' Sc`k' Sw`k' Ec`k' Ew`k' Scw`k' Ec Ew Scw, by (countrycode countryname)
la var RCA`k' "Revealed Comparative Advantage (group `k' products)"
la var Sc`k' "Share of group `k' in country total exports"
la var Sw`k' "Share of group `k' in world's total exports"
la var Scw`k' "Share of countries' exports in world's exports (group `k')"
la var Ec`k' "Country total exports (`k' group)"
la var Ew`k' "World's total exports (`k' group)"
la var Ec "Country total exports"
la var Ew "World's total exports"
la var Scw "Share of countries' total exports in world's total exports"

save first`k'.dta, replace
}
foreach k in TOTAL_NR FORESTRY FUEL METAL MINERAL FOUR_IR ICT TECH{
merge 1:1 countrycode using "first`k'.dta" 
drop _merge
}
gen year=`i'
save second`i'.dta, replace
}

use second2018.dta, clear
forvalues i = 1996/2017{
append using "second`i'.dta"
}

la var countrycode "3-letter country name abbreviation"
la var countryname "Countries' full names"
la var year "1996-2018"
sort countrycode year
order year, before (countrycode)
order RCATECH ScTECH SwTECH EcTECH EwTECH ScwTECH, after (ScwICT)

*Merging trade database with previously prepared country-level databases
merge m:m countrycode using "resource_rents.dta" 
drop if _merge==2
drop _merge

merge m:m countrycode using "pwt_19962018.dta" 
drop if _merge==2
drop _merge

merge m:m countrycode using "income_classification.dta"
drop if _merge==2
drop _merge
order CLS2018 developed, before (Ec)

merge m:m countrycode using "control_variables.dta"
drop if _merge==2
drop _merge

save TheWorldEconomy_ZarachParteka_BaselineData.dta, replace

*Deleting all preliminary databases used beforehand to built baseline database
forvalues i = 1996/2018 {
erase trade-data-`i'.dta
erase country-level-indicators-`i'.dta
erase second`i'.dta
}

foreach k in TOTAL_NR FORESTRY FUEL METAL MINERAL FOUR_IR ICT TECH{
erase first`k'.dta
}
********************************************************************************

