**********************
*PLEASE CITE PAPER AS:
*Zarach, Z. H., Parteka, A. (2023). Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization. The World Economy

***********************************************
*IF YOU USE REPLICATION PACKAGE PLEASE CITE AS:
*Zarach, Z. H., & Parteka, A. (2023). Data accompanying the paper: "Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization" (Zarach and Parteka, The World Economy, 2023) [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/2cf4-9e23

**************************************
*THIS DO.FILE CREATES SELECTED FIGURES
**************************************
clear all
set more off
cd "D:\NR_PRODUCTIVITY"
**********
*MAIN TEXT
**********

//Figure 1//
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

collapse (mean) EwTOTAL_NR_res EwTECH_res (sum) EcTOTAL_NR_res EcTECH_res, by (year developed)

graph twoway (line EwTOTAL_NR_res year, lcolor(black) lpattern(solid) lwidth(thick))  (line EcTOTAL_NR_res year if developed==1, lcolor(black) lpattern(longdash) lwidth(thick)) (line EcTOTAL_NR_res year if developed!=1, lcolor(black) lpattern(shortdash) lwidth(thick)), ytitle("NR (billion USD)", size(medsmall)) ylabel(0(500)4500, angle(horizontal)) xtitle("") xlabel(1996(2)2018, angle(vertical)) legend(on color(black) box fcolor(white) lcolor(white) region(lcolor(white)) row(1)) legend(order(1 "ALL COUNTRIES" 2 "DEVELOPED" 3 "DEVELOPING")) graphregion(color(white) margin(small))  name(TOTALNR) 

graph twoway (line EwTECH_res year, lcolor(black) lpattern(solid) lwidth(thick))  (line EcTECH_res year if developed==1, lcolor(black) lpattern(longdash) lwidth(thick)) (line EcTECH_res year if developed!=1, lcolor(black) lpattern(shortdash) lwidth(thick)), ytitle("TECH (billion USD)", size(medsmall)) ylabel(0(1000)10000, angle(horizontal)) xtitle("") xlabel(1996(2)2018, angle(vertical)) legend(on color(black) box fcolor(white) lcolor(white) region(lcolor(white)) row(1)) legend(order(1 "ALL COUNTRIES" 2 "DEVELOPED" 3 "DEVELOPING")) graphregion(color(white) margin(small))  name(TECH) 

graph combine TOTALNR TECH, iscale(0.7) ysize(10)  xsize(20)  graphregion(color(white))

//Figure 2//
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

lowess EwFORESTRY year, generate (fit_FORESTRY)
lowess EwFUEL year, generate (fit_FUEL)
lowess EwMETAL year, generate (fit_METAL)
lowess EwMINERAL year, generate (fit_MINERAL)

collapse fit_FORESTRY fit_FUEL fit_METAL fit_MINERAL, by(year)

gen zero=0
gen S_FORESTRY=fit_FORESTRY/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_FUEL=(fit_FORESTRY + fit_FUEL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_METAL=(fit_FORESTRY + fit_FUEL + fit_METAL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_MINERAL=(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
graph drop _all

twoway (rarea zero S_FORESTRY year, color(black) lpattern (solid) lwidth(medium)) (rarea S_FORESTRY S_FUEL year, lpattern (solid) lcolor (gs4) color(gs4) lwidth(medium)) (rarea S_FUEL S_METAL year, lpattern (solid) lcolor (gs10) color(gs10) lwidth(medium)) (rarea S_METAL S_MINERAL year, lpattern (solid) lcolor (gs15) color(gs15) lwidth(medium)), xtitle("") ytitle("") xlabel(1996(2)2018, angle(vertical)) ylabel(0(10)100, angle(horizontal))  legend(row(1) order(1 "FORESTRY" 2 "FUEL" 3 "METAL" 4 "MINERAL") size(medium) region(lpattern(blank))) graphregion(color(white)) name(figure2) scheme(s2mono)

//Figure 3//
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

graph twoway (scatter shareTOTAL_NR shareTECH if year==2018 & shareTECH<upperadj_shareTECH_2018 & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareTECH if year==2018 & shareTECH<upperadj_shareTECH_2018 & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018, lcolor(cranberry)), title("A.NR vs TECH", position(11) size(medium)) ytitle(NR export share (%)) xtitle(TECH export share (%)) legend(off) name(shareTECH)
graph twoway (scatter RCATOTAL_NR RCATECH if year==2018 & RCATECH<upperadj_RCATECH_2018 & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCATECH if year==2018 & RCATECH<upperadj_RCATECH_2018 & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in TECH products (RCA index))  legend(off) name(RCATECH)

graph twoway (scatter shareTOTAL_NR shareICT if year==2018 & shareICT<upperadj_shareICT_2018 & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareICT if year==2018 & shareICT<upperadj_shareICT_2018 & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018, lcolor(cranberry)), title("B.NR vs ICT", position(11) size(medium)) ytitle(NR export share (%)) xtitle(ICT export share (%)) legend(off) name(shareICT)
graph twoway (scatter RCATOTAL_NR RCAICT if year==2018 & RCAICT<upperadj_RCAICT_2018 & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAICT if year==2018 & RCAICT<upperadj_RCAICT_2018 & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in ICT products (RCA index)) legend(off) name(RCAICT)

graph twoway (scatter shareTOTAL_NR shareFOUR_IR if year==2018 & shareFOUR_IR<upperadj_shareFOUR_IR_2018 & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareFOUR_IR if year==2018 & shareFOUR_IR<upperadj_shareFOUR_IR_2018 & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018, lcolor(cranberry)), title("C.NR vs 4IR", position(11) size(medium)) ytitle(NR export share (%)) xtitle(4IR export share (%)) legend(off) name(shareFOUR_IR)
graph twoway (scatter RCATOTAL_NR RCAFOUR_IR if year==2018 & RCAFOUR_IR<upperadj_RCAFOUR_IR_2018 & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAFOUR_IR if year==2018 & RCAFOUR_IR<upperadj_RCAFOUR_IR_2018 & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in 4IR products (RCA index)) legend(off) name(RCAFOUR_IR)

graph combine shareTECH RCATECH shareICT RCAICT shareFOUR_IR RCAFOUR_IR, iscale(0.7) rows(3) cols(2) ysize(20)  xsize(13)  graphregion(color(white))

//Figure 4//
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

graph twoway (scatter shareTOTAL_NR shareTECH if year==1996 & shareTECH<upperadj_shareTECH_1996 & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareTECH if year==1996 & shareTECH<upperadj_shareTECH_1996 & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996, lcolor(cranberry)), title("A.NR vs TECH", position(11) size(medium)) ytitle(NR export share (%)) xtitle(TECH export share (%)) legend(off) name(shareTECH)
graph twoway (scatter RCATOTAL_NR RCATECH if year==1996 & RCATECH<upperadj_RCATECH_1996 & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCATECH if year==1996 & RCATECH<upperadj_RCATECH_1996 & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in TECH products (RCA index))  legend(off) name(RCATECH)

graph twoway (scatter shareTOTAL_NR shareICT if year==1996 & shareICT<upperadj_shareICT_1996 & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareICT if year==1996 & shareICT<upperadj_shareICT_1996 & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996, lcolor(cranberry)), title("B.NR vs ICT", position(11) size(medium)) ytitle(NR export share (%)) xtitle(ICT export share (%)) legend(off) name(shareICT)
graph twoway (scatter RCATOTAL_NR RCAICT if year==1996 & RCAICT<upperadj_RCAICT_1996 & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAICT if year==1996 & RCAICT<upperadj_RCAICT_1996 & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in ICT products (RCA index)) legend(off) name(RCAICT)

graph twoway (scatter shareTOTAL_NR shareFOUR_IR if year==1996 & shareFOUR_IR<upperadj_shareFOUR_IR_1996 & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareFOUR_IR if year==1996 & shareFOUR_IR<upperadj_shareFOUR_IR_1996 & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996, lcolor(cranberry)), title("C.NR vs 4IR", position(11) size(medium)) ytitle(NR export share (%)) xtitle(4IR export share (%)) legend(off) name(shareFOUR_IR)
graph twoway (scatter RCATOTAL_NR RCAFOUR_IR if year==1996 & RCAFOUR_IR<upperadj_RCAFOUR_IR_1996 & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAFOUR_IR if year==1996 & RCAFOUR_IR<upperadj_RCAFOUR_IR_1996 & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in 4IR products (RCA index)) legend(off) name(RCAFOUR_IR)

graph combine shareTECH RCATECH shareICT RCAICT shareFOUR_IR RCAFOUR_IR, iscale(0.7) rows(3) cols(2) ysize(20)  xsize(13)  graphregion(color(white))

//Figure 5//
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

foreach k in Egypt Georgia Iran Latvia Oman{
graph twoway (line shareTOTAL_NR year if countryname=="`k'", lcolor(black) lpattern(solid) lwidth(medthick)) (line shareTECH year if countryname=="`k'", lcolor(cranberry) lpattern(longdash) lwidth(medthick)), title("`k'") ytitle("") xtitle("") legend(size(small) on color(black) box fcolor(white) lcolor(white) region(lcolor(black)) row(1)) legend(order(1 "NR share in total exports (%)" 2 "TECH products share in total exports (%)")) graphregion(color(white) margin(small))  name(`k') 
}
graph twoway (line shareTOTAL_NR year if countryname=="Saudi Arabia", lcolor(black) lpattern(solid) lwidth(medthick)) (line shareTECH year if countryname=="Saudi Arabia", lcolor(cranberry) lpattern(longdash) lwidth(medthick)), title("Saudi Arabia") ytitle("") xtitle("") legend(size(small) on color(black) box fcolor(white) lcolor(white) region(lcolor(black)) row(1)) legend(order(1 "NR share in total exports (%)" 2 "TECH products share in total exports (%)")) graphregion(color(white) margin(small))  name(SaudiArabia) 

graph combine Egypt Georgia Iran Latvia Oman SaudiArabia, iscale(0.7) rows(3) cols(2) ysize(20) xsize(18) graphregion(color(white))


***********
*APPENDIX A
***********

//Figure A.1//
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 
keep if developed!=1

lowess EcFORESTRY year, generate (fit_FORESTRY)
lowess EcFUEL year, generate (fit_FUEL)
lowess EcMETAL year, generate (fit_METAL)
lowess EcMINERAL year, generate (fit_MINERAL)

collapse fit_FORESTRY fit_FUEL fit_METAL fit_MINERAL, by(year)

gen zero=0
gen S_FORESTRY=fit_FORESTRY/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_FUEL=(fit_FORESTRY + fit_FUEL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_METAL=(fit_FORESTRY + fit_FUEL + fit_METAL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_MINERAL=(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
graph drop _all

twoway (rarea zero S_FORESTRY year, color(black) lpattern (solid) lwidth(medium)) (rarea S_FORESTRY S_FUEL year, lpattern (solid) lcolor (gs4) color(gs4) lwidth(medium)) (rarea S_FUEL S_METAL year, lpattern (solid) lcolor (gs10) color(gs10) lwidth(medium)) (rarea S_METAL S_MINERAL year, lpattern (solid) lcolor (gs15) color(gs15) lwidth(medium)), xtitle("") ytitle("") xlabel(1996(2)2018, angle(vertical)) ylabel(0(10)100, angle(horizontal))  legend(row(1) order(1 "FORESTRY" 2 "FUEL" 3 "METAL" 4 "MINERAL") size(medium) region(lpattern(blank))) graphregion(color(white)) name(figureA1) scheme(s2mono)

//Figure A.2//
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 
keep if developed==1

lowess EcFORESTRY year, generate (fit_FORESTRY)
lowess EcFUEL year, generate (fit_FUEL)
lowess EcMETAL year, generate (fit_METAL)
lowess EcMINERAL year, generate (fit_MINERAL)

collapse fit_FORESTRY fit_FUEL fit_METAL fit_MINERAL, by(year)

gen zero=0
gen S_FORESTRY=fit_FORESTRY/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_FUEL=(fit_FORESTRY + fit_FUEL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_METAL=(fit_FORESTRY + fit_FUEL + fit_METAL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
gen S_MINERAL=(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)/(fit_FORESTRY + fit_FUEL + fit_METAL + fit_MINERAL)*100
graph drop _all

twoway (rarea zero S_FORESTRY year, color(black) lpattern (solid) lwidth(medium)) (rarea S_FORESTRY S_FUEL year, lpattern (solid) lcolor (gs4) color(gs4) lwidth(medium)) (rarea S_FUEL S_METAL year, lpattern (solid) lcolor (gs10) color(gs10) lwidth(medium)) (rarea S_METAL S_MINERAL year, lpattern (solid) lcolor (gs15) color(gs15) lwidth(medium)), xtitle("") ytitle("") xlabel(1996(2)2018, angle(vertical)) ylabel(0(10)100, angle(horizontal))  legend(row(1) order(1 "FORESTRY" 2 "FUEL" 3 "METAL" 4 "MINERAL") size(medium) region(lpattern(blank))) graphregion(color(white)) name(figureA2) scheme(s2mono)

//Figure A.3// 
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

graph twoway (scatter shareTOTAL_NR shareTECH if developed!=1 & year==2018 & shareTECH<upperadj_shareTECH_2018b & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareTECH if developed!=1 & year==2018 & shareTECH<upperadj_shareTECH_2018b & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018b, lcolor(cranberry)), title("A.NR vs TECH", position(11) size(medium)) ytitle(NR export share (%)) xtitle(TECH export share (%)) legend(off) name(shareTECH)
graph twoway (scatter RCATOTAL_NR RCATECH if developed!=1 & year==2018 & RCATECH<upperadj_RCATECH_2018b & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCATECH if developed!=1 & year==2018 & RCATECH<upperadj_RCATECH_2018b & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018b, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in TECH products (RCA index))  legend(off) name(RCATECH)

graph twoway (scatter shareTOTAL_NR shareICT if developed!=1 & year==2018 & shareICT<upperadj_shareICT_2018b & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareICT if developed!=1 & year==2018 & shareICT<upperadj_shareICT_2018b & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018b, lcolor(cranberry)), title("B.NR vs ICT", position(11) size(medium)) ytitle(NR export share (%)) xtitle(ICT export share (%)) legend(off) name(shareICT)
graph twoway (scatter RCATOTAL_NR RCAICT if developed!=1 & year==2018 & RCAICT<upperadj_RCAICT_2018b & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAICT if developed!=1 & year==2018 & RCAICT<upperadj_RCAICT_2018b & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018b, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in ICT products (RCA index)) legend(off) name(RCAICT)

graph twoway (scatter shareTOTAL_NR shareFOUR_IR if developed!=1 & year==2018 & shareFOUR_IR<upperadj_shareFOUR_IR_2018b & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareFOUR_IR if developed!=1 & year==2018 & shareFOUR_IR<upperadj_shareFOUR_IR_2018b & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018b, lcolor(cranberry)), title("C.NR vs 4IR", position(11) size(medium)) ytitle(NR export share (%)) xtitle(4IR export share (%)) legend(off) name(shareFOUR_IR)
graph twoway (scatter RCATOTAL_NR RCAFOUR_IR if developed!=1 & year==2018 & RCAFOUR_IR<upperadj_RCAFOUR_IR_2018b & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAFOUR_IR if developed!=1 & year==2018 & RCAFOUR_IR<upperadj_RCAFOUR_IR_2018b & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018b, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in 4IR products (RCA index)) legend(off) name(RCAFOUR_IR)

graph combine shareTECH RCATECH shareICT RCAICT shareFOUR_IR RCAFOUR_IR, iscale(0.7) rows(3) cols(2) ysize(20)  xsize(13)  graphregion(color(white))

//Figure A.4// 
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

graph twoway (scatter shareTOTAL_NR shareTECH if developed==1 & year==2018 & shareTECH<upperadj_shareTECH_2018a & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareTECH if developed==1 & year==2018 & shareTECH<upperadj_shareTECH_2018a & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018a, lcolor(cranberry)), title("A.NR vs TECH", position(11) size(medium)) ytitle(NR export share (%)) xtitle(TECH export share (%)) legend(off) name(shareTECH)
graph twoway (scatter RCATOTAL_NR RCATECH if developed==1 & year==2018 & RCATECH<upperadj_RCATECH_2018a & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCATECH if developed==1 & year==2018 & RCATECH<upperadj_RCATECH_2018a & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018a, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in TECH products (RCA index))  legend(off) name(RCATECH)

graph twoway (scatter shareTOTAL_NR shareICT if developed==1 & year==2018 & shareICT<upperadj_shareICT_2018a & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareICT if developed==1 & year==2018 & shareICT<upperadj_shareICT_2018a & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018a, lcolor(cranberry)), title("B.NR vs ICT", position(11) size(medium)) ytitle(NR export share (%)) xtitle(ICT export share (%)) legend(off) name(shareICT)
graph twoway (scatter RCATOTAL_NR RCAICT if developed==1 & year==2018 & RCAICT<upperadj_RCAICT_2018a & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAICT if developed==1 & year==2018 & RCAICT<upperadj_RCAICT_2018a & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018a, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in ICT products (RCA index)) legend(off) name(RCAICT)

graph twoway (scatter shareTOTAL_NR shareFOUR_IR if developed==1 & year==2018 & shareFOUR_IR<upperadj_shareFOUR_IR_2018a & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareFOUR_IR if developed==1 & year==2018 & shareFOUR_IR<upperadj_shareFOUR_IR_2018a & shareTOTAL_NR<upperadj_shareTOTAL_NR_2018a, lcolor(cranberry)), title("C.NR vs 4IR", position(11) size(medium)) ytitle(NR export share (%)) xtitle(4IR export share (%)) legend(off) name(shareFOUR_IR)
graph twoway (scatter RCATOTAL_NR RCAFOUR_IR if developed==1 & year==2018 & RCAFOUR_IR<upperadj_RCAFOUR_IR_2018a & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAFOUR_IR if developed==1 & year==2018 & RCAFOUR_IR<upperadj_RCAFOUR_IR_2018a & RCATOTAL_NR<upperadj_RCATOTAL_NR_2018a, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in 4IR products (RCA index)) legend(off) name(RCAFOUR_IR)

graph combine shareTECH RCATECH shareICT RCAICT shareFOUR_IR RCAFOUR_IR, iscale(0.7) rows(3) cols(2) ysize(20)  xsize(13)  graphregion(color(white))

//Figure A.5// 
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

graph twoway (scatter shareTOTAL_NR shareTECH if developed!=1 & year==1996 & shareTECH<upperadj_shareTECH_1996b & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareTECH if developed!=1 & year==1996 & shareTECH<upperadj_shareTECH_1996b & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996b, lcolor(cranberry)), title("A.NR vs TECH", position(11) size(medium)) ytitle(NR export share (%)) xtitle(TECH export share (%)) legend(off) name(shareTECH)
graph twoway (scatter RCATOTAL_NR RCATECH if developed!=1 & year==1996 & RCATECH<upperadj_RCATECH_1996b & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCATECH if developed!=1 & year==1996 & RCATECH<upperadj_RCATECH_1996b & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996b, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in TECH products (RCA index))  legend(off) name(RCATECH)

graph twoway (scatter shareTOTAL_NR shareICT if developed!=1 & year==1996 & shareICT<upperadj_shareICT_1996b & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareICT if developed!=1 & year==1996 & shareICT<upperadj_shareICT_1996b & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996b, lcolor(cranberry)), title("B.NR vs ICT", position(11) size(medium)) ytitle(NR export share (%)) xtitle(ICT export share (%)) legend(off) name(shareICT)
graph twoway (scatter RCATOTAL_NR RCAICT if developed!=1 & year==1996 & RCAICT<upperadj_RCAICT_1996b & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAICT if developed!=1 & year==1996 & RCAICT<upperadj_RCAICT_1996b & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996b, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in ICT products (RCA index)) legend(off) name(RCAICT)

graph twoway (scatter shareTOTAL_NR shareFOUR_IR if developed!=1 & year==1996 & shareFOUR_IR<upperadj_shareFOUR_IR_1996b & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareFOUR_IR if developed!=1 & year==1996 & shareFOUR_IR<upperadj_shareFOUR_IR_1996b & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996b, lcolor(cranberry)), title("C.NR vs 4IR", position(11) size(medium)) ytitle(NR export share (%)) xtitle(4IR export share (%)) legend(off) name(shareFOUR_IR)
graph twoway (scatter RCATOTAL_NR RCAFOUR_IR if developed!=1 & year==1996 & RCAFOUR_IR<upperadj_RCAFOUR_IR_1996b & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996b, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAFOUR_IR if developed!=1 & year==1996 & RCAFOUR_IR<upperadj_RCAFOUR_IR_1996b & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996b, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in 4IR products (RCA index)) legend(off) name(RCAFOUR_IR)

graph combine shareTECH RCATECH shareICT RCAICT shareFOUR_IR RCAFOUR_IR, iscale(0.7) rows(3) cols(2) ysize(20)  xsize(13)  graphregion(color(white))

//Figure A.6// 
graph drop _all
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 

graph twoway (scatter shareTOTAL_NR shareTECH if developed==1 & year==1996 & shareTECH<upperadj_shareTECH_1996a & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareTECH if developed==1 & year==1996 & shareTECH<upperadj_shareTECH_1996a & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996a, lcolor(cranberry)), title("A.NR vs TECH", position(11) size(medium)) ytitle(NR export share (%)) xtitle(TECH export share (%)) legend(off) name(shareTECH)
graph twoway (scatter RCATOTAL_NR RCATECH if developed==1 & year==1996 & RCATECH<upperadj_RCATECH_1996a & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCATECH if developed==1 & year==1996 & RCATECH<upperadj_RCATECH_1996a & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996a, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in TECH products (RCA index))  legend(off) name(RCATECH)

graph twoway (scatter shareTOTAL_NR shareICT if developed==1 & year==1996 & shareICT<upperadj_shareICT_1996a & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareICT if developed==1 & year==1996 & shareICT<upperadj_shareICT_1996a & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996a, lcolor(cranberry)), title("B.NR vs ICT", position(11) size(medium)) ytitle(NR export share (%)) xtitle(ICT export share (%)) legend(off) name(shareICT)
graph twoway (scatter RCATOTAL_NR RCAICT if developed==1 & year==1996 & RCAICT<upperadj_RCAICT_1996a & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAICT if developed==1 & year==1996 & RCAICT<upperadj_RCAICT_1996a & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996a, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in ICT products (RCA index)) legend(off) name(RCAICT)

graph twoway (scatter shareTOTAL_NR shareFOUR_IR if developed==1 & year==1996 & shareFOUR_IR<upperadj_shareFOUR_IR_1996a & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess shareTOTAL_NR shareFOUR_IR if developed==1 & year==1996 & shareFOUR_IR<upperadj_shareFOUR_IR_1996a & shareTOTAL_NR<upperadj_shareTOTAL_NR_1996a, lcolor(cranberry)), title("C.NR vs 4IR", position(11) size(medium)) ytitle(NR export share (%)) xtitle(4IR export share (%)) legend(off) name(shareFOUR_IR)
graph twoway (scatter RCATOTAL_NR RCAFOUR_IR if developed==1 & year==1996 & RCAFOUR_IR<upperadj_RCAFOUR_IR_1996a & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996a, msymbol(smcircle) mcolor(black) mlabel(labels) graphregion(color(white))) (lowess RCATOTAL_NR RCAFOUR_IR if developed==1 & year==1996 & RCAFOUR_IR<upperadj_RCAFOUR_IR_1996a & RCATOTAL_NR<upperadj_RCATOTAL_NR_1996a, lcolor(cranberry)), ytitle(specialisation in NR products (RCA index)) xtitle(specialisation in 4IR products (RCA index)) legend(off) name(RCAFOUR_IR)

graph combine shareTECH RCATECH shareICT RCAICT shareFOUR_IR RCAFOUR_IR, iscale(0.7) rows(3) cols(2) ysize(20)  xsize(13)  graphregion(color(white))
