**********************
*PLEASE CITE PAPER AS:
*Zarach, Z. H., Parteka, A. (2023). Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization. The World Economy

***********************************************
*IF YOU USE REPLICATION PACKAGE PLEASE CITE AS:
*Zarach, Z. H., & Parteka, A. (2023). Data accompanying the paper: "Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization" (Zarach and Parteka, The World Economy, 2023) [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/2cf4-9e23

**********************************************************
*THIS DO.FILE CALCULATES ECONOMETRIC MODELS - MAIN RESULTS
**********************************************************
clear all
set more off
cd "D:\NR_PRODUCTIVITY"
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 
xtset countryid year

//Model 1a (page 16)//
//Table 3 in the main text//
**Assessing the role of natural resources in the productivity growth process (baseline model)**

//Table 3//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) i.year, gmm2s robust
quietly outreg2 using "TABLE3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') i.year, gmm2s robust
quietly outreg2 using "TABLE3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Model 1b (page 16)//
//Table 4 in the main text//
**Extending model (1a) by adding a set of control variables that could potentially affect productivity growth-NR relationship**

//Table 4//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) l.INV l.RDexpend l.HC i.year, gmm2s robust
quietly outreg2 using "TABLE4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') l.INV l.RDexpend l.HC i.year, gmm2s robust
quietly outreg2 using "TABLE4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Model 2 (page 16)//
**Extending model (1b) by adding the share of technologically advanced products in total exports (checking whether technological specialisation affects the relationship between NR and productivity growth**
//Tables 5-7 in the main text//

//Table 5//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareFOUR_IR = l2.shareTOTAL_NR l2.shareFOUR_IR) i.year, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareFOUR_IR = l2.share`k' l2.shareFOUR_IR) i.year, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table 6//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareICT = l2.shareTOTAL_NR l2.shareICT) i.year, gmm2s robust
quietly outreg2 using "TABLE6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareICT = l2.share`k' l2.shareICT) i.year, gmm2s robust
quietly outreg2 using "TABLE6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table 7//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareTECH = l2.shareTOTAL_NR l2.shareTECH) i.year, gmm2s robust
quietly outreg2 using "TABLE7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareTECH = l2.share`k' l2.shareTECH) i.year, gmm2s robust
quietly outreg2 using "TABLE7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}
