**********************
*PLEASE CITE PAPER AS:
*Zarach, Z. H., Parteka, A. (2023). Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization. The World Economy

***********************************************
*IF YOU USE REPLICATION PACKAGE PLEASE CITE AS:
*Zarach, Z. H., & Parteka, A. (2023). Data accompanying the paper: "Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization" (Zarach and Parteka, The World Economy, 2023) [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/2cf4-9e23

**********************************************************************
*THIS DO.FILE CALCULATES ECONOMETRIC MODELS - ROBUSTNESS CHECKS RESULTS
**********************************************************************
clear all
set more off
cd "D:\NR_PRODUCTIVITY"
use "DATA\TheWorldEconomy_ZarachParteka_FinalData.dta", clear 
xtset countryid year

//Model 1a (page 16)//
//Tables B1, B3, B5 and B13 in Appendix B//
**Assessing the role of natural resources in the productivity growth process (baseline model)**

//Table B1//
xi: ivreg2 glabprod_res l.labprod_res (l.total=l2.total) i.year, gmm2s robust
quietly outreg2 using "TABLE_B1.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("total NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in coal forest oil gas mineral{
xi: ivreg2 glabprod_res l.labprod_res (l.`k'=l2.`k') i.year, gmm2s robust
quietly outreg2 using "TABLE_B1.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B3//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B5//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B13//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B13.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B13.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Model 1b (page 16)//
//Tables B2, B4, B6 and B14 in Appendix B//
**Extending model (1a) by adding a set of control variables that could potentially affect productivity growth-NR relationship**

//Table B2//
xi: ivreg2 glabprod_res l.labprod_res (l.total=l2.total) l.INV l.RDexpend l.HC i.year, gmm2s robust
quietly outreg2 using "TABLE_B2.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("total NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in coal forest oil gas mineral{
xi: ivreg2 glabprod_res l.labprod_res (l.`k'=l2.`k') l.INV l.RDexpend l.HC i.year, gmm2s robust
quietly outreg2 using "TABLE_B2.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B4//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) l.INV l.RDexpend l.HC i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') l.INV l.RDexpend l.HC i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B6//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) l.INV l.RDexpend l.HC i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') l.INV l.RDexpend l.HC i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B14//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR=l2.shareTOTAL_NR) l.INV l.RDexpend l.HC i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B14.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k'=l2.share`k') l.INV l.RDexpend l.HC i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B14.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Model 2 (page 16)//
**Extending model (1b) by adding the share of technologically advanced products in total exports (checking whether technological specialisation affects the relationship between NR and productivity growth**
//Tables B7-B12 and B15-B17 in Appendix B//

//Table B7//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareFOUR_IR = l2.shareTOTAL_NR l2.shareFOUR_IR) i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareFOUR_IR = l2.share`k' l2.shareFOUR_IR) i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B8//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareICT = l2.shareTOTAL_NR l2.shareICT) i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B8.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareICT = l2.share`k' l2.shareICT) i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B8.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B9//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareTECH = l2.shareTOTAL_NR l2.shareTECH) i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B9.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareTECH = l2.share`k' l2.shareTECH) i.year if developed==1, gmm2s robust
quietly outreg2 using "TABLE_B9.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B10//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareFOUR_IR = l2.shareTOTAL_NR l2.shareFOUR_IR) i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B10.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareFOUR_IR = l2.share`k' l2.shareFOUR_IR) i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B10.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B11//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareICT = l2.shareTOTAL_NR l2.shareICT) i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B11.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareICT = l2.share`k' l2.shareICT) i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B11.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B12//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareTECH = l2.shareTOTAL_NR l2.shareTECH) i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B12.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareTECH = l2.share`k' l2.shareTECH) i.year if developed!=1, gmm2s robust
quietly outreg2 using "TABLE_B12.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B15//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareFOUR_IR = l2.shareTOTAL_NR l2.shareFOUR_IR) i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B15.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareFOUR_IR = l2.share`k' l2.shareFOUR_IR) i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B15.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B16//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareICT = l2.shareTOTAL_NR l2.shareICT) i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B16.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareICT = l2.share`k' l2.shareICT) i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B16.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}

//Table B17//
xi: ivreg2 glabprod_res l.labprod_res (l.shareTOTAL_NR l.shareTECH = l2.shareTOTAL_NR l2.shareTECH) i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B17.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("TOTAL NR") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel replace

foreach k in FUEL FORESTRY MINERAL METAL{
xi: ivreg2 glabprod_res l.labprod_res (l.share`k' l.shareTECH = l2.share`k' l2.shareTECH) i.year if glabprod_res < p99 & glabprod_res > p1, gmm2s robust
quietly outreg2 using "TABLE_B17.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) paren ctitle("`k'") drop(_I* o._I*) nor2 nocons e(widstat idstat idp) excel append
}
